searchData={"items":[{"type":"module","title":"CircleCI","doc":"","ref":"CircleCI.html"},{"type":"function","title":"CircleCI.raw/4","doc":"Run a client operation and return the raw Operation or Error\n\nNormal client operation calls return only the response body. This function can be useful when\nthe caller needs additional information, such as data from the response headers.\n\nThe `args` passed to this function should not include the `opts` argument usually available on\nclient operations. Instead, any such options should be passed as the final argument to `raw/4`.","ref":"CircleCI.html#raw/4"},{"type":"function","title":"Example - CircleCI.raw/4","doc":"iex> CircleCI.raw(CircleCI.Users, :get_authenticated, [])\n    {:ok, %CircleCI.Operation{}}","ref":"CircleCI.html#raw/4-example"},{"type":"protocol","title":"CircleCI.Auth","doc":"Protocol for extracting API authentication tokens from application structs\n\nCredentials can be passed to operations using the `auth` option as strings for tokens. Sometimes, it's more\nconvenient to pass a struct — like as a user struct — and extract the auth token from that.\n\nBy implementing this protocol, the client can extract an auth token from the given struct without\nadditional work by the caller.","ref":"CircleCI.Auth.html"},{"type":"protocol","title":"Example - CircleCI.Auth","doc":"defimpl CircleCI.Auth, for: MyApp.User do\n      def to_auth(%MyApp.User{github_token: token}), do: token\n    end","ref":"CircleCI.Auth.html#module-example"},{"type":"function","title":"CircleCI.Auth.to_auth/1","doc":"Extract an auth token from the given struct\n\nThe returned data should be in the form of a string (for a Bearer token) or a 2-tuple (for a Basic\nAuth user/password pair).","ref":"CircleCI.Auth.html#to_auth/1"},{"type":"type","title":"CircleCI.Auth.auth/0","doc":"Auth token accepted by the client","ref":"CircleCI.Auth.html#t:auth/0"},{"type":"type","title":"CircleCI.Auth.t/0","doc":"All the types that implement this protocol.","ref":"CircleCI.Auth.html#t:t/0"},{"type":"module","title":"CircleCI.Config","doc":"Configuration for the API client and plugins\n\n> #### Note {:.info}\n>\n> Functions in this module is unlikely to be used directly by applications. Instead, they are\n> useful for plugins. See `CircleCI.Plugin` for more information.\n\nCallers of API operation functions can pass in some configuration directly using the final\nargument. Configuration passed in this way always takes precedence over global configuration.\n\n    # Local options:\n    CircleCI.Workflow.get_workflow_by_id(\"workflow-123\", server: \"https://circleci.com/api/v2\")\n\n    # Application environment (ex. config/config.exs):\n    config :circleci, server: \"https://circleci.com/api/v2\"","ref":"CircleCI.Config.html"},{"type":"module","title":"Options - CircleCI.Config","doc":"The following configuration is available using **local options**:\n\n  * `server` (URL): API server to use. Useful if the client would like to target a CircleCI\n    Enterprise installation. Defaults to `https://circleci.com/api/v2`.\n\n  * `stack` (list of plugins): Plugins to control the execution of client requests. See\n    `CircleCI.Plugin` for more information. Defaults to the default stack below.\n\n  * `version` (string): API version to use. Setting this option is not recommended, as the default\n    value is the version of the API used to generate this client's code. Overriding it risks the\n    client raising an error. To see the default value, open `.api-version` in the root of this\n    project.\n\n  * `wrap` (boolean): Whether to wrap the results of the API call in a tagged tuple. When\n    `true`, the response body will be wrapped as `{:ok, response}` on success or\n    `{:error, error}` otherwise. When false, the Operation or Error is returned directly.\n    Defaults to `true`.\n\n    **Note**: Unwrapped responses violate the type specifications provided for each client\n    operation. To avoid Dialyzer errors, consider using `CircleCI.raw/4` instead.\n\nThe following configuration is available using the **application environment**:\n\n  * `app_name` (string): Name of the application using this client, used for User Agent and\n    logging purposes.\n\n  * `default_auth` (`t:CircleCI.Auth.auth/0`): Default API authentication credentials to use when\n    authentication was not provided for a request.\n\n  * `server` (URL): API server to use. Defaults to `https://circleci.com/api/v2`.\n\n  * `stack` (list of plugins): Plugins to control the execution of client requests. See\n    `CircleCI.Plugin` for more information. Defaults to the default stack below.","ref":"CircleCI.Config.html#module-options"},{"type":"module","title":"Plugins - CircleCI.Config","doc":"Client requests are implemented using a series of plugins. Each plugin accepts a\n`CircleCI.Operation` struct and returns either a modified operation or an error. The collection of\nplugins configured for a request form a **stack**.\n\nThe default stack uses `Jason` as a serializer/deserializer and `HTTPoison` as an HTTP client:\n\n```elixir\n[\n  {CircleCI.Plugin.JasonSerializer, :encode_body, []},\n  {CircleCI.Plugin.HTTPoisonClient, :request, []},\n  {CircleCI.Plugin.JasonSerializer, :decode_body, []},\n  {CircleCI.Plugin.TypedDecoder, :decode_response, []},\n  {CircleCI.Plugin.TypedDecoder, :normalize_errors, []}\n]\n```\n\nIn general, plugins can be defined as 2- or 3-tuples specifying the module and function name and\nany options to pass to the function. For example:\n\n    {MyPlugin, :my_function}\n    #=> MyPlugin.my_function(operation)\n\n    {MyPlugin, :my_function, some: :option}\n    #=> MyPlugin.my_function(operation, some: :option)\n\nBy modifying the stack, applications can easily use a different HTTP client library or serializer.\n\n> #### Warning {:.warning}\n>\n> Stack entries without options, like `{CircleCI.Plugin.TestClient, :request}`, look like keyword\n> list items. If you have stacks configured in multiple Mix environments that all use this\n> 2-tuple format, Elixir will try to merge them as keyword lists. Adding an empty options\n> element to any stack item will prevent this behaviour.","ref":"CircleCI.Config.html#module-plugins"},{"type":"function","title":"CircleCI.Config.app_name/0","doc":"Get the configured app name","ref":"CircleCI.Config.html#app_name/0"},{"type":"function","title":"Example - CircleCI.Config.app_name/0","doc":"iex> Config.app_name()\n    \"Test App\"","ref":"CircleCI.Config.html#app_name/0-example"},{"type":"function","title":"CircleCI.Config.default_auth/0","doc":"Get the configured default auth credentials","ref":"CircleCI.Config.html#default_auth/0"},{"type":"function","title":"Example - CircleCI.Config.default_auth/0","doc":"iex> Config.default_auth()\n    {\"client_one\", \"abc123\"}","ref":"CircleCI.Config.html#default_auth/0-example"},{"type":"function","title":"CircleCI.Config.plugin_config/4","doc":"Get configuration namespaced with a plugin module\n\nPlugins can provide a keyword list of options (such as a pre-merged keyword list of the plugin\noptions argument and the operation's options) to be used if the given key is present. Otherwise,\nthe response will fall back to the application environment given with the following form:\n\n    config :circleci, MyPlugin, some: :option\n\nWhere `MyPlugin` is the `plugin` module given as the second argument.\n\nSee `plugin_config!/3` for a variant that raises if the configuration is not found.","ref":"CircleCI.Config.html#plugin_config/4"},{"type":"function","title":"CircleCI.Config.plugin_config!/3","doc":"Get configuration namespaced with a plugin module, or raise if not present\n\nPlugins can provide a keyword list of options (such as a pre-merged keyword list of the plugin\noptions argument and the operation's options) to be used if the given key is present. Otherwise,\nthe response will fall back to the application environment given with the following form:\n\n    config :circleci, MyPlugin, some: :option\n\nWhere `MyPlugin` is the `plugin` module given as the second argument.\n\nSee `plugin_config/4` for a variant that accepts a default value.","ref":"CircleCI.Config.html#plugin_config!/3"},{"type":"function","title":"CircleCI.Config.server/1","doc":"Get the configured default API server, or `https://circleci.com/api/v2` by default","ref":"CircleCI.Config.html#server/1"},{"type":"function","title":"Example - CircleCI.Config.server/1","doc":"iex> Config.server([])\n    \"https://circleci.com/api/v2\"\n\n    iex> Config.server(server: \"https://example.com/api/v2\")\n    \"https://example.com/api/v2\"","ref":"CircleCI.Config.html#server/1-example"},{"type":"function","title":"CircleCI.Config.stack/1","doc":"Get the configured plugin stack","ref":"CircleCI.Config.html#stack/1"},{"type":"function","title":"Example - CircleCI.Config.stack/1","doc":"iex> Config.stack([])\n    [\n      {CircleCI.Plugin.JasonSerializer, :encode_body},\n      # ...\n    ]","ref":"CircleCI.Config.html#stack/1-example"},{"type":"function","title":"Default - CircleCI.Config.stack/1","doc":"The following stack is the default if none is configured or passed as an option:\n\n```elixir\n[\n  {CircleCI.Plugin.JasonSerializer, :encode_body, []},\n  {CircleCI.Plugin.HTTPoisonClient, :request, []},\n  {CircleCI.Plugin.JasonSerializer, :decode_body, []},\n  {CircleCI.Plugin.TypedDecoder, :decode_response, []},\n  {CircleCI.Plugin.TypedDecoder, :normalize_errors, []}\n]\n```","ref":"CircleCI.Config.html#stack/1-default"},{"type":"function","title":"CircleCI.Config.wrap/1","doc":"Whether to wrap the result\n\nPassing `wrap: false` to a client call can be useful if you need additional information about\nthe response, such as response headers.","ref":"CircleCI.Config.html#wrap/1"},{"type":"function","title":"Example - CircleCI.Config.wrap/1","doc":"iex> Config.wrap([])\n    true\n\n    iex> Config.wrap(wrap: false)\n    false","ref":"CircleCI.Config.html#wrap/1-example"},{"type":"type","title":"CircleCI.Config.plugin/0","doc":"Plugin definition\n\nPlugins are defined in the stack using module and function tuples with an optional keyword list.\nOptions, if provided, will be passed as the second argument.","ref":"CircleCI.Config.html#t:plugin/0"},{"type":"exception","title":"CircleCI.Error","doc":"Exception struct used for communicating errors from the client\n\n> #### Note {:.info}\n>\n> Functions in this module is unlikely to be used directly by applications. Instead, they are\n> useful for plugins. See `CircleCI.Plugin` for more information.\n\nThis error covers errors generated by the client (for example, HTTP connection errors) as well as\nerrors returned from the CircleCI API (for example, Not Found errors).","ref":"CircleCI.Error.html"},{"type":"exception","title":"Fields - CircleCI.Error","doc":"* `code` (integer): Status code of the API response, if a response was received.\n\n  * `message` (string): Human-readable message describing the error. Defaults to a generic\n    `\"Unknown Error\"`.\n\n  * `operation` (`t:Operation.t/0`): Operation at the time of the error.\n\n  * `reason` (atom): Easily-matched atom for common errors, like `:not_found`. Defaults to a\n    generic `:error`. See **Error Reasons** below for a list of possible values.\n\n  * `source` (term): Cause of the error. This could be an operation, an API error response, or\n    something else.\n\n  * `stacktrace` (`t:Exception.stacktrace/0`): Stacktrace from the time of the error. Defaults\n    to a stack that terminates with the calling function, but can be overridden (for example,\n    if a `__STACKTRACE__` is available in a `rescue` block).\n\n  * `step` (plugin): Plugin active at the time of the error (expressed as a tuple containing the\n    module and function).\n\nUsers of the library can match on the information in the `code` and `source` fields to extract\nadditional information.","ref":"CircleCI.Error.html#module-fields"},{"type":"exception","title":"Error Reasons - CircleCI.Error","doc":"Although plugins may use any atom for the `reason` field, the following have predetermined\nmeanings:\n\n  * `:invalid_auth`: The credential (`:auth` option) provided is invalid.\n\n  * `:invalid_version`: The version (`:version` option) provided is invalid.\n\n  * `:not_found`: A resource or route was not found. Note that CircleCI may return this kind of\n    response when authentication is required to see a resource.\n\n  * `:oauth_restricted`: The OAuth credentials are valid, but the requested resource is owned\n    by an organization that requires admin approval for OAuth apps.\n\n  * `:rate_limited`: The client has exceeded a primary or secondary rate limit. Secondary rate\n    limits have a distinct `message` field with further information.\n\n  * `:requires_auth`: The requested endpoint requires an authenticated user, and no auth\n    credentials were given.\n\n  * `:unauthorized`: Valid authentication credentials were given, but the current user does not\n    have permission to perform this action.","ref":"CircleCI.Error.html#module-error-reasons"},{"type":"function","title":"CircleCI.Error.new/1","doc":"Create a new error struct with the given fields\n\nThe current stacktrace is automatically filled in to the resulting error. Callers should specify\nthe status `code` (if available), a `message`, the original `operation`, the `source` of the\nerror, and which `step` or plugin is currently active.","ref":"CircleCI.Error.html#new/1"},{"type":"type","title":"CircleCI.Error.t/0","doc":"CircleCI API client error","ref":"CircleCI.Error.html#t:t/0"},{"type":"module","title":"CircleCI.Operation","doc":"Defines a struct that tracks client requests\n\n> #### Note {:.info}\n>\n> This module is unlikely to be used directly by applications. Instead, functions in this module\n> are useful for plugins. See `CircleCI.Plugin` for more information.","ref":"CircleCI.Operation.html"},{"type":"module","title":"Fields - CircleCI.Operation","doc":"* `private` (map): This field is useful for plugins that need to store information. Plugins\n    should be careful to namespace their data to avoid overlap. By default, this map will include\n    an `__auth__` key with the auth credentials used for the request, `__info__` containing the\n    information that originated the request, and `__opts__` containing all of the options passed\n    in to the original operation function.\n\n  * `request_body` (term): For requests that support request bodies, this key will hold the data\n    to be included in an outgoing request. Depending on the plugins involved, this key may have\n    Elixir terms (like a map) or strings (such as a JSON-encoded string).\n\n  * `request_headers` (list of headers): HTTP headers to be included in the outgoing request.\n    These are specified as tuples with the name of the header and its value.\n\n  * `request_method` (atom): HTTP verb of the outgoing request.\n\n  * `request_params` (keyword): URL-based query parameters for the outgoing request.\n\n  * `request_server` (string): URL scheme and hostname of the API server for the request.\n\n  * `request_types` (list of types): OpenAPI type specifications for the request body. These are\n    specified as tuples with the Content-Type and the type specification.\n\n  * `request_url` (string): URL path of the outgoing request.\n\n  * `response_body` (term): For responses that include response bodies, this key will hold the\n    data from the response. Depending on the plugins involved, this key may have raw response data\n    (such as a JSON-encoded string) or Elixir terms (like a map).\n\n  * `response_code` (integer): Response status code.\n\n  * `response_headers` (list of headers): HTTP headers from the response. These are specified as\n    tuples with the name of the header and its value.\n\n  * `response_types` (list of types): OpenAPI type specifications for the response body. These are\n    specified as tuples with the status code and the type specification.","ref":"CircleCI.Operation.html#module-fields"},{"type":"function","title":"CircleCI.Operation.get_caller/1","doc":"Get the client's calling function and original arguments\n\nThis level of introspection is meant for testing purposes, although other plugins can take\nadvantage of it as necessary.","ref":"CircleCI.Operation.html#get_caller/1"},{"type":"function","title":"CircleCI.Operation.get_options/1","doc":"Get the options passed to the client request","ref":"CircleCI.Operation.html#get_options/1"},{"type":"function","title":"Examples - CircleCI.Operation.get_options/1","doc":"iex> operation = %Operation{private: %{__opts__: [server: \"https://api.github.com\"]}}\n    iex> Operation.get_options(operation)\n    [server: \"https://api.github.com\"]","ref":"CircleCI.Operation.html#get_options/1-examples"},{"type":"function","title":"CircleCI.Operation.get_response_header/2","doc":"Get the value of a response header\n\nIf response headers have not been filled in — or the response did not have the given header —\nthen `nil` will be returned.","ref":"CircleCI.Operation.html#get_response_header/2"},{"type":"function","title":"Examples - CircleCI.Operation.get_response_header/2","doc":"iex> operation = %Operation{response_headers: [{\"Content-Type\", \"application/json\"}]}\n    iex> Operation.get_response_header(operation, \"Content-Type\")\n    \"application/json\"\n\n    iex> operation = %Operation{response_headers: []}\n    iex> Operation.get_response_header(operation, \"ETag\")\n    nil","ref":"CircleCI.Operation.html#get_response_header/2-examples"},{"type":"function","title":"CircleCI.Operation.put_private/3","doc":"Put information in the operation's private data store\n\nExisting data with the same key will be overridden.","ref":"CircleCI.Operation.html#put_private/3"},{"type":"function","title":"Example - CircleCI.Operation.put_private/3","doc":"iex> operation = %Operation{private: %{}}\n    iex> operation = Operation.put_private(operation, :my_plugin_data, \"abc123\")\n    %Operation{private: %{my_plugin_data: \"abc123\"}} = operation","ref":"CircleCI.Operation.html#put_private/3-example"},{"type":"function","title":"CircleCI.Operation.put_request_header/3","doc":"Add a request header to an outgoing operation\n\nThis function makes no effort to deduplicate headers.","ref":"CircleCI.Operation.html#put_request_header/3"},{"type":"function","title":"Example - CircleCI.Operation.put_request_header/3","doc":"iex> operation = %Operation{request_headers: []}\n    iex> operation = Operation.put_request_header(operation, \"Content-Type\", \"application/json\")\n    %Operation{request_headers: [{\"Content-Type\", \"application/json\"}]} = operation","ref":"CircleCI.Operation.html#put_request_header/3-example"},{"type":"type","title":"CircleCI.Operation.auth/0","doc":"","ref":"CircleCI.Operation.html#t:auth/0"},{"type":"type","title":"CircleCI.Operation.header/0","doc":"","ref":"CircleCI.Operation.html#t:header/0"},{"type":"type","title":"CircleCI.Operation.headers/0","doc":"","ref":"CircleCI.Operation.html#t:headers/0"},{"type":"type","title":"CircleCI.Operation.method/0","doc":"","ref":"CircleCI.Operation.html#t:method/0"},{"type":"type","title":"CircleCI.Operation.request_type/0","doc":"","ref":"CircleCI.Operation.html#t:request_type/0"},{"type":"type","title":"CircleCI.Operation.request_types/0","doc":"","ref":"CircleCI.Operation.html#t:request_types/0"},{"type":"type","title":"CircleCI.Operation.response_type/0","doc":"","ref":"CircleCI.Operation.html#t:response_type/0"},{"type":"type","title":"CircleCI.Operation.response_types/0","doc":"","ref":"CircleCI.Operation.html#t:response_types/0"},{"type":"type","title":"CircleCI.Operation.t/0","doc":"Operation struct for tracking client requests from start to finish","ref":"CircleCI.Operation.html#t:t/0"},{"type":"type","title":"CircleCI.Operation.type/0","doc":"Type annotation produced by [OpenAPI](https://github.com/aj-foster/open-api-generator)","ref":"CircleCI.Operation.html#t:type/0"},{"type":"module","title":"CircleCI.Plugin","doc":"Plugins provide functionality for the API client\n\n> #### Note {:.info}\n>\n> This module is unlikely to be used directly by applications. The documentation contained here\n> is useful for developers who would like to implement new functionality for the client.\n\nThis library has no opinions on how to complete API requests. Instead of requiring a particular\nHTTP client or JSON serializer, requests are completed using a series of plugins called a\n**stack**. To modify the behavior of the client, applications can add or modify plugins.\n\nPlugins are functions that accept a `CircleCI.Operation` struct — and any options — and return\neither an `:ok` or an `:error` tuple:\n\n    alias CircleCI.{Error, Operation}\n\n    @spec my_plugin(Operation.t(), keyword) :: {:ok, Operation.t()} | {:error, Error.t()}\n    def my_plugin(operation, opts) do\n      # ...\n    end\n\nAn `:error` tuple will immediately stop the stack and return the error. An `:ok` tuple will\ncontinue running the stack with the modified operation struct. If the stack concludes with a\nsuccessful operation, the `response_body` is returned.","ref":"CircleCI.Plugin.html"},{"type":"module","title":"Options - CircleCI.Plugin","doc":"Plugins may accept options that modify their behavior. It is recommended that they consider\noptions from three sources:\n\n1. Options passed to the operation function (available in the `__opts__` key of the operation\n  struct's private field). This is likely to include options not relevant to the plugin.\n2. Options passed to the plugin definition (available as the second argument of the plugin\n  function).\n3. Options defined globally using the application environment.\n\nThis hierarchy can be accomplished by calling `Keyword.merge/2` on the plugin options argument and\nthe operation's options (order matters!), then calling `CircleCI.Config.plugin_config/4` to\nincorporate the application environment as a fallback. (For required options, the sibling\nfunction `CircleCI.Config.plugin_config!/3` is also available.)\n\nIn this way, plugins can be configured at all levels of the code:\n\n    # Highest precedence: options from the caller\n    CircleCI.Repos.get(\"aj-foster\", \"open-api-github\", some: :option)\n\n    # Medium precedence: options in the plugin definition\n    {MyPlugin, :my_function, some: :option}\n\n    # Lowest precedence: global configuration\n    config :circleci, MyPlugin, some: :option\n\nPlugins should take care to document their available options and avoid naming collisions.","ref":"CircleCI.Plugin.html#module-options"},{"type":"module","title":"CircleCI.Plugin.HTTPoisonClient","doc":"","ref":"CircleCI.Plugin.HTTPoisonClient.html"},{"type":"function","title":"CircleCI.Plugin.HTTPoisonClient.request/2","doc":"","ref":"CircleCI.Plugin.HTTPoisonClient.html#request/2"},{"type":"module","title":"CircleCI.Plugin.JasonSerializer","doc":"","ref":"CircleCI.Plugin.JasonSerializer.html"},{"type":"function","title":"CircleCI.Plugin.JasonSerializer.decode_body/2","doc":"","ref":"CircleCI.Plugin.JasonSerializer.html#decode_body/2"},{"type":"function","title":"CircleCI.Plugin.JasonSerializer.encode_body/2","doc":"","ref":"CircleCI.Plugin.JasonSerializer.html#encode_body/2"},{"type":"module","title":"CircleCI.Plugin.TypedDecoder","doc":"Transform map responses into well-typed structs\n\nIn a normal client stack, the HTTP request is followed by a JSON decoder such as\n`CircleCI.Plugin.JasonSerializer`. If the JSON library/plugin does not support decoding typed\nstructs, then a separate step is necessary to transform the map responses into structs like\n`CircleCI.Workflow`.\n\nThis module provides a two plugins: `decode_response/2` and `normalize_errors/2`, that accept no\nconfiguration. `decode_response/2` uses the type information available in the operation and each\nmodule's `__fields__/1` functions to decode the data. `normalize_errors/2` changes API error\nresponses into standard `CircleCI.Error` results. It is recommended to run these plugins towards\nthe end of the stack, after decoding JSON responses.\n\nThe normalized errors will be `CircleCI.Error` structs with relevant reason fields where possible.","ref":"CircleCI.Plugin.TypedDecoder.html"},{"type":"module","title":"Special Cases - CircleCI.Plugin.TypedDecoder","doc":"There are a few special cases where the decoder must make an inference about which type to use.\nIf you find that you are unable to decode something, please open an issue with information about\nthe operation and types involved.\n\nUnion types often require this kind of inference. This module handles them on a case-by-case\nbasis using required keys to determine the correct type. Some of these are done on a \"best\nguess\" basis due to a lack of official documentation.","ref":"CircleCI.Plugin.TypedDecoder.html#module-special-cases"},{"type":"function","title":"CircleCI.Plugin.TypedDecoder.decode/2","doc":"Manually decode a response\n\nThis function takes a parsed response and decodes it using the given type. It is intended for\nuse in testing scenarios only. For regular API requests, use `decode_response/2` as part of the\nclient stack.","ref":"CircleCI.Plugin.TypedDecoder.html#decode/2"},{"type":"function","title":"CircleCI.Plugin.TypedDecoder.decode_response/2","doc":"Decode a response body based on type information from the operation and schemas","ref":"CircleCI.Plugin.TypedDecoder.html#decode_response/2"},{"type":"function","title":"CircleCI.Plugin.TypedDecoder.normalize_errors/2","doc":"Change API error responses into `CircleCI.Error` results","ref":"CircleCI.Plugin.TypedDecoder.html#normalize_errors/2"},{"type":"module","title":"CircleCI.Job","doc":"Provides API endpoint related to job","ref":"CircleCI.Job.html"},{"type":"function","title":"CircleCI.Job.get_job_details/3","doc":"Get job details\n\nReturns job details.","ref":"CircleCI.Job.html#get_job_details/3"},{"type":"type","title":"CircleCI.Job.get_job_details_200_json_resp/0","doc":"","ref":"CircleCI.Job.html#t:get_job_details_200_json_resp/0"},{"type":"type","title":"CircleCI.Job.get_job_details_default_json_resp/0","doc":"","ref":"CircleCI.Job.html#t:get_job_details_default_json_resp/0"},{"type":"type","title":"CircleCI.Job.t/0","doc":"","ref":"CircleCI.Job.html#t:t/0"},{"type":"module","title":"CircleCI.Pipeline","doc":"Provides API endpoints related to pipeline","ref":"CircleCI.Pipeline.html"},{"type":"function","title":"CircleCI.Pipeline.get_pipeline_by_id/2","doc":"Get a pipeline by ID\n\nReturns a pipeline by the pipeline ID.","ref":"CircleCI.Pipeline.html#get_pipeline_by_id/2"},{"type":"function","title":"CircleCI.Pipeline.get_pipeline_by_number/3","doc":"Get a pipeline by pipeline number\n\nReturns a pipeline by the pipeline number.","ref":"CircleCI.Pipeline.html#get_pipeline_by_number/3"},{"type":"type","title":"CircleCI.Pipeline.get_pipeline_by_id_default_json_resp/0","doc":"","ref":"CircleCI.Pipeline.html#t:get_pipeline_by_id_default_json_resp/0"},{"type":"type","title":"CircleCI.Pipeline.get_pipeline_by_number_default_json_resp/0","doc":"","ref":"CircleCI.Pipeline.html#t:get_pipeline_by_number_default_json_resp/0"},{"type":"type","title":"CircleCI.Pipeline.t/0","doc":"","ref":"CircleCI.Pipeline.html#t:t/0"},{"type":"module","title":"CircleCI.Workflow","doc":"Provides API endpoints related to workflow","ref":"CircleCI.Workflow.html"},{"type":"function","title":"CircleCI.Workflow.get_workflow_by_id/2","doc":"Get a workflow\n\nReturns summary fields of a workflow by ID.","ref":"CircleCI.Workflow.html#get_workflow_by_id/2"},{"type":"function","title":"CircleCI.Workflow.list_workflow_jobs/2","doc":"Get a workflow's jobs\n\nReturns a sequence of jobs for a workflow.","ref":"CircleCI.Workflow.html#list_workflow_jobs/2"},{"type":"type","title":"CircleCI.Workflow.get_workflow_by_id_default_json_resp/0","doc":"","ref":"CircleCI.Workflow.html#t:get_workflow_by_id_default_json_resp/0"},{"type":"type","title":"CircleCI.Workflow.list_workflow_jobs_200_json_resp/0","doc":"","ref":"CircleCI.Workflow.html#t:list_workflow_jobs_200_json_resp/0"},{"type":"type","title":"CircleCI.Workflow.list_workflow_jobs_default_json_resp/0","doc":"","ref":"CircleCI.Workflow.html#t:list_workflow_jobs_default_json_resp/0"},{"type":"type","title":"CircleCI.Workflow.t/0","doc":"","ref":"CircleCI.Workflow.html#t:t/0"},{"type":"module","title":"CircleCI.Encoder","doc":"","ref":"CircleCI.Encoder.html"},{"type":"module","title":"CircleCI.PipelineErrors","doc":"Provides struct and type for a PipelineErrors","ref":"CircleCI.PipelineErrors.html"},{"type":"type","title":"CircleCI.PipelineErrors.t/0","doc":"","ref":"CircleCI.PipelineErrors.html#t:t/0"},{"type":"module","title":"CircleCI.PipelineTrigger","doc":"Provides struct and type for a PipelineTrigger","ref":"CircleCI.PipelineTrigger.html"},{"type":"type","title":"CircleCI.PipelineTrigger.t/0","doc":"","ref":"CircleCI.PipelineTrigger.html#t:t/0"},{"type":"module","title":"CircleCI.PipelineTriggerActor","doc":"Provides struct and type for a PipelineTriggerActor","ref":"CircleCI.PipelineTriggerActor.html"},{"type":"type","title":"CircleCI.PipelineTriggerActor.t/0","doc":"","ref":"CircleCI.PipelineTriggerActor.html#t:t/0"},{"type":"module","title":"CircleCI.PipelineTriggerParameters","doc":"Provides struct and type for a PipelineTriggerParameters","ref":"CircleCI.PipelineTriggerParameters.html"},{"type":"type","title":"CircleCI.PipelineTriggerParameters.t/0","doc":"","ref":"CircleCI.PipelineTriggerParameters.html#t:t/0"},{"type":"module","title":"CircleCI.PipelineVcs","doc":"Provides struct and type for a PipelineVcs","ref":"CircleCI.PipelineVcs.html"},{"type":"type","title":"CircleCI.PipelineVcs.t/0","doc":"","ref":"CircleCI.PipelineVcs.html#t:t/0"},{"type":"module","title":"CircleCI.PipelineVcsCommit","doc":"Provides struct and type for a PipelineVcsCommit","ref":"CircleCI.PipelineVcsCommit.html"},{"type":"type","title":"CircleCI.PipelineVcsCommit.t/0","doc":"","ref":"CircleCI.PipelineVcsCommit.html#t:t/0"},{"type":"extras","title":"Overview","doc":"# CircleCI API Client for Elixir\n\n[![Hex.pm](https://img.shields.io/hexpm/v/circleci_client)](https://hex.pm/packages/circleci_client)\n[![Documentation](https://img.shields.io/badge/hex-docs-blue)](https://hexdocs.pm/circleci_client)\n[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)\n\n_The ergonomics of a hand-crafted client with the API coverage of generated code._\n\n---\n\nThis library uses an [OpenAPI Code Generator](https://github.com/aj-foster/open-api-generator) that has the flexibility to wrangle the generated code into an ergonomic client.\n\nFurthermore, this library has no opinions about what you use for HTTP requests, serialization, etc.\nInstead it allows users to define their own **stack** of plugins, many of which are provided here.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"This library is available on Hex.pm.\nAdd the dependency in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:circleci_client, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen install the dependency using `mix deps.get`.","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Overview","doc":"This library comes with a common default set of configuration.\nTo use it successfully, you will need to install `HTTPoison` and `Jason`.\n(Remember, these libraries can easily be switched out by changing the `stack` configuration.\nSee `CircleCI.Config` for more information.)\n\nSome good up-and-running configuration to set:\n\n* `app_name` will include the name of your application in the User Agent so CircleCI can contact you if they notice any problems.\n\n```elixir\nconfig :circleci,\n  app_name: \"MyApp\"\n```\n\nFor more information about configuration, see the documentation for `CircleCI.Config`.","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Overview","doc":"All of the client operations are generated based on the OpenAPI description provided by CircleCI.\nIn general, you can expect to find:\n\n```elixir\nCircleCI.Resource.operation(path1, path2, ..., body, opts)\n```\n\nWhere:\n\n* `Resource` is the name of the resource as tagged by CircleCI, like `Workflow`.\n* `operation` is the name of the route, like `get` or `get_workflow_by_id`.\n* The first arguments are path parameters, such as `workflow_id` in `/workflow/{workflow_id}`.\n* If the request accepts a body, then there will be a `body` parameter.\n* Finally, all operations accept a keyword list of options.\n\nThe options accepted by operations may differ depending on your chosen stack.\nHowever, the following are always available:\n\n* `auth` (string or struct implementing `CircleCI.Auth`) Credentials to use for the request.\n* `server` (URL including scheme) Base API server to use, such as `https://circleci.com/api/v2`.\n\nWhenever CircleCI specifies a named schema as the response type for an operation, an Elixir struct will be returned.\nNote that some schemas have been collapsed into a single struct (like `CircleCI.Workflow`) where not all of the fields may be filled in.\nHowever, responses are still properly typed by their type specifications.","ref":"readme.html#usage"},{"type":"extras","title":"Contributing - Overview","doc":"Because this library uses a code generator for the majority of its mass, there are two modes of contribution.\nPlease consider these when creating issues or opening pull requests:\n\n* If the generated code is out of date, the fix may be as simple as running `mix gen.api` using the latest OpenAPI description.\n* If the client isn't working as expected, the fix may be more involved and require careful thought and versioning.\n\nFor more on what this means to you as a contributor, please see the [contribution guidelines](CONTRIBUTING.md).","ref":"readme.html#contributing"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, caste, color, religion, or sexual\nidentity and orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the overall\n  community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or advances of\n  any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email address,\n  without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official e-mail address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement\n[by email](mailto:public@aj-foster.com).\nAll complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.","ref":"code_of_conduct.html#1-correction"},{"type":"extras","title":"2. Warning - Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series of\nactions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or permanent\nban.","ref":"code_of_conduct.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.","ref":"code_of_conduct.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior, harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within the\ncommunity.","ref":"code_of_conduct.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.1, available at\n[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1].\n\nCommunity Impact Guidelines were inspired by\n[Mozilla's code of conduct enforcement ladder][Mozilla CoC].\n\nFor answers to common questions about this code of conduct, see the FAQ at\n[https://www.contributor-covenant.org/faq][FAQ]. Translations are available at\n[https://www.contributor-covenant.org/translations][translations].\n\n[homepage]: https://www.contributor-covenant.org\n[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html\n[Mozilla CoC]: https://github.com/mozilla/diversity\n[FAQ]: https://www.contributor-covenant.org/faq\n[translations]: https://www.contributor-covenant.org/translations","ref":"code_of_conduct.html#attribution"},{"type":"extras","title":"Contributing","doc":"# Contribution Guidelines\n\nHello there.\nThank you for your interest in contributing to this project.\nGitHub has a large API that would be impossible to maintain a client for without help.\n\nReading and following the guidelines in this document is an act of kindness and respect for other contributors.\nWith your help, we can address issues, make changes, and work together efficiently.","ref":"contributing.html"},{"type":"extras","title":"Ways to Contribute - Contributing","doc":"There are many ways to contribute to this project:\n\n* Anyone can use the `mix api.gen` task (see below) to update the library using the latest OpenAPI description.\n* Users of the client can report issues related to the client itself and propose solutions.\n* Users and library authors can contribute plugins (see below) for new integrations.\n* Everyone can help improve documentation and support others in Discussions.\n* Anyone can assist in the triage of bugs, identifying root causes, and proposing solutions.\n\nPlease keep in mind the intended scope of this package: to provide a GitHub REST API client that balances an ergonomic user experience with the maintainability of code generation.\nAssume that the GitHub OpenAPI description that serves as input to this library will change often, and manually changing the output is impractical.","ref":"contributing.html#ways-to-contribute"},{"type":"extras","title":"Ground Rules - Contributing","doc":"All contributions to this project must align with the [code of conduct](CODE_OF_CONDUCT.md).\nBeyond that, we ask:\n\n* Please be kind. Maintaining this project is not paid work.\n* Please create an issue before embarking on major refactors or new features.\n* Let's make a reasonable effort to support commonly-used 3rd-party integrations.","ref":"contributing.html#ground-rules"},{"type":"extras","title":"Workflows - Contributing","doc":"If you're interested in doing something specific, here are some guidelines:","ref":"contributing.html#workflows"},{"type":"extras","title":"Bugs and Blockers - Contributing","doc":"Please use [GitHub Issues](https://github.com/challengr-apps/circleci_client/issues) to report reproducible bugs.","ref":"contributing.html#bugs-and-blockers"},{"type":"extras","title":"Feature Requests and Ideas - Contributing","doc":"Please use [GitHub Discussions](https://github.com/challengr-apps/circleci_client/discussions) to share requests and ideas for improvements to the library.","ref":"contributing.html#feature-requests-and-ideas"},{"type":"extras","title":"Updating the Generated Code - Contributing","doc":"If you intend to open a PR with updates to the generated code based on the latest GitHub OpenAPI description, please read carefully:\n\n1. Please use the latest commit from the [official repository](https://circleci.com/docs/api/v2/index.html) at the time of your contribution.\n2. Use `mix api.gen default openapi.yaml` to regenerate the code.\n3. Please do not make any other changes in the same PR (for example, changing this library's version).\n\nIf you run into any unexpected issues while generating the code, please open an issue.\n\nThank you for your help!","ref":"contributing.html#updating-the-generated-code"},{"type":"extras","title":"Implementing Changes - Contributing","doc":"If you've decided to take on the implementation of a new feature or fix, please remember to avoid changing files in `operations/` and `schemas/`.\nThese directories contain generated code, and therefore will be overwritten.\nIf something in there needs to be changed, please start a discussion on [the generator repo](https://github.com/aj-foster/open-api-generator).","ref":"contributing.html#implementing-changes"},{"type":"extras","title":"Releases - Contributing","doc":"For maintainers, the process of releasing this package to [Hex.pm](https://hex.pm/packages/circleci_client) centers around git tags.\nTo make a new release:\n\n1. Update the Changelog with a new header that has today's date and the new version.\n  Include any missing notes from changes since the last release, and any additional upgrade instructions users may need.\n2. Update the `@version` number in `mix.exs`.\n  The form should be `X.Y.Z`, with optional suffixes, but no leading `v`.\n3. Update the **Installation** instructions in `README.md` to have the newest non-suffixed version number.\n4. Commit the above changes with a generic commit message, such as `Release X.Y.Z`.\n5. Tag the commit as `X.Y.Z`, with optional suffixes, but no leading `v`.\n6. Push the commits and tag (for example, `git push origin main --tags`).\n7. Observe the GitHub Action titled **Release**.\n  This action automatically publishes the package to Hex.pm.","ref":"contributing.html#releases"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2024 Colin Harris\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}